import Texture from "./Texture.js";

/**
 * Load a texture file.
 *
 * @param {String} texturePath Path to the texture file.
 * @param {Object} [textureOptions] An object with the following properties:
 * @param {Boolean} [textureOptions.checkTransparency=false] Do a more exhaustive check for texture transparency by looking at the alpha channel of each pixel.
 * @param {Boolean} [textureOptions.decode=false] Whether to decode the texture.
 * @param {Boolean} [textureOptions.keepSource=false] Whether to keep the source image contents in memory.
 * @returns {Promise} A promise resolving to a Texture object.
 *
 * @private
 */
export async function loadTexture(
  texturePath,
  mtlPath,
  options,
  textureOptions,
) {
  textureOptions = textureOptions ?? {};
  textureOptions.checkTransparency = textureOptions.checkTransparency ?? false;
  textureOptions.decode = textureOptions.decode ?? false;
  textureOptions.keepSource = textureOptions.keepSource ?? false;

  const { source, name, extension } = await options.resolver(
    texturePath,
    mtlPath,
  );

  const texture = new Texture();
  texture.source = source;
  texture.name = name;
  texture.extension = extension;

  if (extension === ".png") {
    // await options.decodePng(texture, textureOptions);
    await options.decodePng(texture, textureOptions);
  } else if (extension === ".jpg" || extension === ".jpeg") {
    // options.decodeJpeg(texture, textureOptions);
    options.decodeJpeg(texture, textureOptions);
  }

  return texture;
}
